/* Copyright 2013-2016 Reahl Software Services (Pty) Ltd. All rights reserved. */
/*
    This file is part of Reahl.

    Reahl is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation; version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/* -------------------------------------------------------------------------------- Fonts */
h1 { 
    font-size: 150%;
    font-weight: bold;
    text-decoration: underline; 
    margin-bottom: 1em;
}
h2 { 
    font-size: 120%; 
    font-weight: bold; 
}
h3 { 
    font-size: 110%; 
    font-weight: bold; 
}

p {
   margin: 1em 0 1em 0;
}

#bd { 
  font-size: 110%; 
}

/* ================================================================================ Widget styling */


/* -- messages -- */
p.error { color: red; }
p.feedback { font-size: 85%; }


/* -- inputs -- */
[required]:before { content: "*" }
[required] { background: #fefeeb; }
input { background: #fbfbf2; }
input.error { background: red; }
label.error { 
  display: block; 
  color: red;
}
label.error:first-letter {
    text-transform: uppercase;
}

/* -- buttons -- */
.reahl-button input { -moz-border-radius: 4px; -webkit-border-radius: 4px; border-radius: 4px; }


/* -- priority -- */
.reahl-priority-primary input, .reahl-priority-primary { font-weight: bold; }
.reahl-priority-secondary { opacity: .7; filter:Alpha(Opacity=70); font-weight: normal; }


/* -- gallery widget -- */
.reahl-gallerywidget {
 text-align: center;
}

.reahl-gallerywidget>div {
 min-height: 400px;
}


/* -- gallery teazer -- */
.reahl-galleryteazer>a {
 text-decoration: none;
 margin-left: .2em;
 color: #fff;
 background-color: #bf8130;
}

.reahl-galleryteazer>a:hover {
 background-color: #3062bf;
}


/* -- pager menu -- */

.reahl-pagemenu {
 margin-left: .2em;
}

.reahl-pagemenu a {
 display: inline-block;
 width: 1.5em;
 padding: 0.1em 0 0 0;
 text-align: center;
 text-decoration: none;
 margin-bottom: .4em;

 background-color: #bf8130;
 color: #b6a792;
}

.reahl-pagemenu a[href] {
 color: #fff;
 background-color: #bf8130;
}

.reahl-pagemenu a:hover {
 background-color: #3062bf;
}



/* -- thumbnail menu -- */

.reahl-thumbnailmenu {
clear: both;
}

a.reahl-thumbnail {
margin: .2em;
margin-bottom: 0;
margin-top: 0;
}




/* -- dialogs -- */
.reahl-dialog {
 background-color: #fff;
 border: .3em ridge #fff;
 border-radius: 0.5em;
 text-align: left;
}

.reahl-titlebar>h1 {
 text-decoration: none;
}

.reahl-titlebar {
 border-bottom: .3em ridge #fff;
 text-align: center;
}

.reahl-dialogbuttons {
 border-top: .3em ridge #fff;
 text-align: right;
}

.reahl-dialogcontent {
 padding: 2em;
}


#navigationaccordion {
  background: #fff; 
}

#navigationaccordion .reahl-accordion-header {
  font-size: 70%;  
  font-weight: lighter;
  text-align: center;
  background: #603e35;
  padding: .8em 0 0 0; 
  margin: 0 0.2em 0 0;
  border-radius: .4em;
  height: 90%;
}

#navigationaccordion .reahl-accordion-header > a {
  text-decoration: none;
  color: #fff;
}
#navigationaccordion .reahl-accordion-content {
  font-size: 100%; 
  padding: .5em;
}


/* -- forms -- */
fieldset>label {
  display: block;
  width: 100%;
  border-bottom: 1px solid #bf8130;
  margin: 1em 0 1em 0;
  font-size: 120%;
}

fieldset>.reahl-labelledinput {
  margin: 1em 0 1em 0.5em; 
}

.action_buttons {
  float: right;
  margin-right: 25%;
  margin-bottom: 2em;
}

.reahl-labelledinput input {
  width: 100%;
}

/* -- labels that are shown over an input -- */
.reahl-labeloverinput > label {
  font-size: 80%;
  padding: .2em;
  padding-left: .5em;
}

.reahl-labeloverinput label.error { 
  background: white;
  opacity: 0.8;
  border: 1px solid red;
}


/* -- cue widgets -- */

.reahl-cueinput>.yui-u {
  width: 32.1%;
}
.reahl-cueinput>.yui-g {
  width: 67.1%;
}
.reahl-cueinput>.yui-g>.yui-u {
  width: 32.1%;
  text-align: left;
}
.reahl-cueinput>.yui-g>.yui-u.first {
  width: 67.1%;
}
.reahl-cueinput a {
  font-size: 85%;
  float: right;
}


.reahl-cueinput input { 
  width: 100%; 
}
.reahl-cueinput input[type="checkbox"] { 
  width: auto; 
}


.reahl-cue {
  position: relative;
  padding: 0;
  margin: 0;
  margin-top: -0.25em;
}

.reahl-cue>* {
  position: absolute;
  margin: 0;
  padding: 0.25em;
  border: 1px solid #BF8130; 

  background:url(/images/cue_arrow.gif) no-repeat 0 .4em;
  background-color:#fff;
  z-index:1;
  padding-left: 1em;
}

/* -- EditionIndex -- */
.editionindex a {
  color: #000;
  text-decoration: none;
}
.editionindex a:hover {
  text-decoration: underline;
}
.editionindex h1 {
  text-decoration: none;
  margin-bottom: 0;
}
.editionindex ul.reahl-menu {
  padding-bottom: 1em;
  padding-top: 1em;
}

.editionindex {
  width: 40%;
  float: left;
  padding: 1em;
  margin: 1em;
  border: 1px dashed #000;
}

.leftlinks .editionindex {
  width: 90%;
  padding: .5em;
  margin: 0;
  border: 1px dashed #000;
}

.editionsbrowser .reahl-pagemenu a {
  width: auto;
  padding: 0 .3em 0 .3em;
}


/*----------------------------- horizontal menu --------*/

ul.reahl-menu li > a {
  color: #fff;
  background: #bf8130; 
}
ul.reahl-menu li > a[href]:hover {
  background: #3062bf; 
}
ul.reahl-menu li.active > a {
  background: #3062bf; 
}
ul.reahl-menu li > a:not([href]) {
  color: #d5d5d5; 
}

ul.reahl-menu li > a {
  padding: 0.4em 0.4em 0.4em 0.4em;
  text-align: center;
  font-weight: bold;
  font-size: 107%;
  text-decoration: none;
}
ul.reahl-menu li > a:hover {
  padding-bottom: 0.4em;
}

/*----------------------------- tabbed pane--------*/

.reahl-tabbedpanel ul.reahl-menu li > a {
  border: none;
  padding: 0;
  color: #000;
  background: #fff; 
}
.reahl-tabbedpanel ul.reahl-menu li > a:hover {
  text-decoration: underline;
  color: #000;
}
.reahl-tabbedpanel ul.reahl-menu li > a:hover {
  background: #fff; 
}
.reahl-tabbedpanel ul.reahl-menu li.active > a {
  background: #fff; 
}


.reahl-tabbedpanel {
  padding: .2em;
}

.reahl-tabbedpanel > div {
  padding: 1em; 
  border: .1em solid #603e35;
  margin-top: -.05em;
}

.reahl-tabbedpanel > ul  {
  position: relative;
  margin: 0;
  padding: 0;
}

.reahl-tabbedpanel > ul > li  {
  border: .1em solid #603e35;
  border-radius: .5em .5em 0 0;
  font-weight: bold;
  font-size: 107%;
  padding: .3em .6em .2em .6em; 
}

.reahl-tabbedpanel > ul > li.active  {
  border-bottom: .1em solid #fff;
}

.reahl-tabbedpanel > ul > li:hover > ul {
  border: .1em solid #603e35;
  background: #fff;
  padding: .5em;
  font-size: 80%;
  white-space: nowrap;
}

.reahl-tabbedpanel > ul > li:hover > ul > li {
  padding-bottom: .3em;
}

.reahl-tabbedpanel article  h1 {
  font-size: 110%;
  margin-bottom: 0;
}

.reahl-tabbedpanel article  footer {
  font-size: 80%;
  margin-bottom: 1em;
  text-indent: .5em;
}


.reahl-slidingpanel .viewport {
    width: 20em;
    height: 10em; 
}

.reahl-slidingpanel > a {
    height: 0;
    width: 0;
    margin: 1em;
}
.reahl-slidingpanel > a > span {
    display: none;
}
.reahl-slidingpanel > a:first-child {
    border-right: 2em solid black;
    border-top: 2em solid transparent;
    border-bottom: 2em solid transparent;
}

.reahl-slidingpanel > a:last-child {
    border-left: 2em solid black;
    border-top: 2em solid transparent;
    border-bottom: 2em solid transparent;
}

/*----------------------------- table --------*/

table {
    color:#333333;
    border-width: 1px;
    border-color: #666666;
    border-collapse: collapse;
}

table>caption { 
    font-size: 150%;
    font-weight: bold;
    text-decoration: none; 
    margin-bottom: 1em;
}

table>thead>tr>th {
    border-width: 1px;
    padding: 8px;
    border-style: solid;
    border-color: #666666;
    background-color: #C1D2E7;
}

table>tbody>tr:nth-child(even) {
    background: #dedede;
}

table>tbody>tr>td {
    border-width: 1px;
    padding: 8px;
    border-style: solid;
    border-color: #666666;
}

.reahl-column-sort > a{
    text-decoration: none;
}

